==> topia-service-replication-2.4.2-sources.jar: org/nuiton/topia/replication/model/ReplicationOperationPhase.java <==
/*
 * #%L
 * ToPIA :: Service Replication
 * 
 * $Id: ReplicationOperationPhase.java 2089 2010-07-26 14:07:15Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.4.2/topia-service-replication/src/main/java/org/nuiton/topia/replication/model/ReplicationOperationPhase.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.topia.replication.model;

import org.nuiton.topia.replication.operation.Duplicate;

/**
 * Une enumeration pour definir quand appliquer une operation.
 * <p/>
 * L'ordre induit par cette enumeration sera utiliser pour trier les operations
 * a realiser sur chaque noeud de replication.
 *
 * @author chemit
 */
public enum ReplicationOperationPhase {

    /** a appliquer avant la duplicate d'un noeud */
    before,
    /**
     * pour dupliquer un noeud (cette phase ne doit etre utilise que sur l'operation
     * de type {@link Duplicate}
     */
    duplicate,
    /** a appliquer apres avoir duplique le noeud */
    after
}

==> topia-service-replication-2.4.3-sources.jar: org/nuiton/topia/replication/model/ReplicationOperationPhase.java <==
/*
 * #%L
 * ToPIA :: Service Replication
 * 
 * $Id: ReplicationOperationPhase.java 2098 2010-08-14 13:54:40Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/topia/tags/topia-2.4.3/topia-service-replication/src/main/java/org/nuiton/topia/replication/model/ReplicationOperationPhase.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.topia.replication.model;

import org.nuiton.topia.replication.operation.Duplicate;

/**
 * Une enumeration pour definir quand appliquer une operation.
 * <p/>
 * L'ordre induit par cette enumeration sera utilisé pour trier les operations
 * a realiser sur chaque noeud de replication.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.2.0
 */
public enum ReplicationOperationPhase {

    /** a appliquer avant la duplicate d'un noeud */
    before,
    /**
     * pour dupliquer un noeud (cette phase ne doit etre utilise que sur l'operation
     * de type {@link Duplicate}
     */
    duplicate,
    /** a appliquer apres avoir duplique le noeud */
    after
}
